@@ -1,7 +1,6 @@
 from ..mixins import ToJsonMixin, FromJsonMixin, ReadMixin, ListMixin, UpdateMixin
 
 
-
 class QuickbooksBaseObject(ToJsonMixin, FromJsonMixin):
     class_dict = {}
     list_dict = {}
@@ -14,7 +13,7 @@ class QuickbooksTransactionEntity(QuickbooksBaseObject):
     def __init__(self):
         self.Id = None
         self.SyncToken = 0
-        self.sparse = "false"
+        self.sparse = False
         self.domain = "QBO"
         self.TxnDate = ""
 
@@ -32,9 +31,19 @@ class MetaData:
         return "Created {0}".format(self.CreateTime)
 
 
+class LinkedTxnMixin(object):
+    def to_linked_txn(self):
+        linked_txn = LinkedTxn()
+        linked_txn.TxnId = self.Id
+        linked_txn.TxnType = self.qbo_object_name
+        linked_txn.TxnLineId = 1
+
+        return linked_txn
+
+
 class Address(ToJsonMixin, FromJsonMixin):
     def __init__(self):
-        self.Id = 0
+        self.Id = None
         self.Line1 = ""
         self.Line2 = ""
         self.City = ""
@@ -114,3 +123,16 @@ class CustomerMemo(QuickbooksBaseObject):
 
     def __unicode__(self):
         return self.Value
+
+
+class MarkupInfo(QuickbooksBaseObject):
+    class_dict = {
+        "PriceLevelRef": Ref,
+    }
+
+    def __init__(self):
+        super(MarkupInfo, self).__init__()
+        self.PercentBased = False
+        self.Value = 0
+        self.Percent = 0
+        self.PriceLevelRef = None
