@@ -1,39 +1,10 @@
-from base import QuickbooksBaseObject, CustomField, Ref, CustomerMemo, Address, EmailAddress, QuickbooksManagedObject
+from base import QuickbooksBaseObject, CustomField, Ref, CustomerMemo, Address, EmailAddress, QuickbooksManagedObject, \
+    LinkedTxnMixin, QuickbooksTransactionEntity, LinkedTxn
 from tax import TxnTaxDetail
-
-class SalesItemLineDetail(QuickbooksBaseObject):
-    class_dict = {
-        "ItemRef": Ref,
-        "TaxCodeRef": Ref
-    }
-
-    def __init__(self):
-        super(SalesItemLineDetail, self).__init__()
-        self.UnitPrice = 0
-        self.Qty = 0
-
-    def __unicode__(self):
-        return str(self.UnitPrice)
+from detailline import DetailLine
 
 
-class EstimateLine(QuickbooksBaseObject):
-    class_dict = {
-        "SalesItemLineDetail": SalesItemLineDetail
-    }
-
-    def __init__(self):
-        super(EstimateLine, self).__init__()
-        self.LineNum = 0
-        self.Amount = 0
-        self.Description = ""
-        self.DetailType = ""
-        self.SalesItemLineDetail = None
-
-    def __unicode__(self):
-        return str(self.Amount)
-
-
-class Estimate(QuickbooksManagedObject):
+class Estimate(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: The Estimate represents a proposal for a financial transaction from a business to a customer
     for goods or services proposed to be sold, including proposed pricing.
@@ -46,10 +17,17 @@ class Estimate(QuickbooksManagedObject):
         "TxnTaxDetail": TxnTaxDetail,
         "CustomerMemo": CustomerMemo,
         "BillEmail": EmailAddress,
+        "DepartmentRef": Ref,
+        "CurrencyRef": Ref,
+        "ClassRef": Ref,
+        "SalesTermRef": Ref,
+        "ShipMethodRef": Ref,
     }
 
     list_dict = {
         "CustomField": CustomField,
+        "LinkedTxn": LinkedTxn,
+        "Line": DetailLine,
     }
 
     qbo_object_name = "Estimate"
@@ -59,16 +37,31 @@ class Estimate(QuickbooksManagedObject):
         self.DocNumber = ""
         self.TxnDate = ""
         self.TxnStatus = ""
+        self.PrivateNote = ""
         self.TotalAmt = 0
-        self.ApplyTaxAfterDiscount = 0
+        self.ExchangeRate = 1
+        self.ApplyTaxAfterDiscount = False
         self.PrintStatus = "NotSet"
         self.EmailStatus = "NotSet"
+        self.DueDate = ""
+        self.ShipDate = ""
+        self.ExpirationDate = ""
+        self.AcceptedBy = ""
+        self.AcceptedDate = ""
+        self.GlobalTaxCalculation = "TaxExcluded"
         self.BillAddr = None
         self.ShipAddr = None
+        self.BillEmail = None
         self.CustomerRef = None
         self.TxnTaxDetail = None
         self.CustomerMemo = None
+        self.ClassRef = None
+        self.SalesTermRef = None
+        self.ShipMethodRef = None
+
         self.CustomField = []
+        self.LinkedTxn = []
+        self.Line = []
 
     def __unicode__(self):
         return str(self.TotalAmt)
