@@ -1,43 +1,10 @@
-from base import QuickbooksBaseObject, Ref, CustomField, QuickbooksManagedObject
+from base import QuickbooksBaseObject, Ref, CustomField, QuickbooksManagedObject, LinkedTxnMixin, Address, \
+    EmailAddress, QuickbooksTransactionEntity, LinkedTxn
 from tax import TxnTaxDetail
+from detailline import DetailLine
 
 
-class SalesItemLineDetail(QuickbooksBaseObject):
-    class_dict = {
-        "ItemRef": Ref,
-        "TaxCodeRef": Ref
-    }
-
-    def __init__(self):
-        super(SalesItemLineDetail, self).__init__()
-        self.UnitPrice = 0
-        self.Qty = 0
-        self.ItemRef = None
-        self.TaxCodeRef = None
-
-    def __unicode__(self):
-        return str(self.UnitPrice)
-
-
-class SalesReceiptLine(QuickbooksBaseObject):
-    class_dict = {
-        "SalesItemLineDetail": SalesItemLineDetail
-    }
-
-    def __init__(self):
-        super(SalesReceiptLine, self).__init__()
-        self.LineNum = ""
-        self.Description = ""
-        self.Amount = 0
-        self.DetailType = ""
-
-        self.SalesItemLineDetail = None
-
-    def __unicode__(self):
-        return str(self.Amount)
-
-
-class SalesReceipt(QuickbooksManagedObject):
+class SalesReceipt(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: SalesReceipt represents the sales receipt that is given to a customer. A sales receipt is
     similar to an invoice. However, for a sales receipt, payment is received as part of the sale of goods and
@@ -50,11 +17,18 @@ class SalesReceipt(QuickbooksManagedObject):
         "TxnTaxDetail": TxnTaxDetail,
         "DepositToAccountRef": Ref,
         "CustomerRef": Ref,
+        "BillAddr": Address,
+        "ShipAddr": Address,
+        "ClassRef": Ref,
+        "BillEmail": EmailAddress,
+        "PaymentMethodRef": Ref,
+        "ShipMethodRef": Ref,
     }
 
     list_dict = {
         "CustomField": CustomField,
-        "Line": SalesReceiptLine,
+        "Line": DetailLine,
+        "LinkedTxn": LinkedTxn
     }
 
     qbo_object_name = "SalesReceipt"
@@ -62,21 +36,38 @@ class SalesReceipt(QuickbooksManagedObject):
     def __init__(self):
         super(SalesReceipt, self).__init__()
         self.DocNumber = ""
+        self.TxnDate = ""
         self.PrivateNote = ""
+        self.CustomerMemo = ""
+        self.ShipDate = ""
+        self.TrackingNum = ""
         self.TotalAmt = 0
         self.PrintStatus = "NotSet"
         self.EmailStatus = "NotSet"
+        self.DeliveryInfo = ""
         self.Balance = 0
         self.PaymentRefNum = ""
+        self.CreditCardPayment = ""
+        self.TxnSource = ""
         self.ApplyTaxAfterDiscount = False
+        self.ExchangeRate = 1
+        self.GlobalTaxCalculation = "TaxExcluded"
 
-        self.DepositToAccountRef = None
-        self.CurrencyRef = None
         self.DepartmentRef = None
-        self.CustomerRef = None
+        self.CurrencyRef = None
         self.TxnTaxDetail = None
+        self.DepositToAccountRef = None
+        self.BillAddr = None
+        self.ShipAddr = None
+        self.ShipMethodRef = None
+        self.BillEmail = None
+        self.CustomerRef = None
+        self.ClassRef = None
+        self.PaymentMethodRef = None
+
         self.CustomField = []
         self.Line = []
+        self.LinkedTxn = []
 
     def __unicode__(self):
         return str(self.TotalAmt)
